@@ -18,6 +18,13 @@
 #'   For patterns recorded in the metadata, all the branches
 #'   will be deleted. For patterns no longer in the metadata,
 #'   branches are left alone.
+#'
+#'   If you plan to delete cloud targets, you may need to set the
+#'   `resources` argument of [tar_option_set()] accordingly.
+#'   If your `_targets.R` file already sets this option,
+#'   [tar_load_globals()] with no arguments is a convenient way
+#'   to set `resources` for your interactive R session.
+#' @inheritSection tar_meta Storage access
 #' @inheritParams tar_validate
 #' @param names Names of the targets to remove from `_targets/objects/`.
 #'   You can supply symbols
@@ -45,9 +52,11 @@ tar_delete <- function(
   cloud = TRUE,
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_delete")
   tar_assert_store(store = store)
   tar_assert_path(path_meta(store))
   meta <- meta_init(path_store = store)$database$read_condensed_data()
+  meta <- as.data.frame(meta)
   names_quosure <- rlang::enquo(names)
   names <- tar_tidyselect_eval(names_quosure, meta$name)
   tar_assert_chr(names, "names arg of tar_delete() must end up as character")
@@ -58,8 +67,9 @@ tar_delete <- function(
     meta$repository == "local"
   local_dynamic_files <- meta$name[index_local_dynamic_files]
   names <- setdiff(names, local_dynamic_files)
+  names <- setdiff(names, meta$name[meta$type == "pattern"])
   if (cloud) {
-    tar_delete_cloud(names = names, meta = meta, path_store = store)
+    tar_delete_cloud_objects(names = names, meta = meta, path_store = store)
   }
   files <- list.files(path_objects_dir(store), all.files = TRUE)
   discard <- intersect(names, files)
@@ -69,7 +79,8 @@ tar_delete <- function(
 
 # Tested in tests/aws/test-delete.R
 # nocov start
-tar_delete_cloud <- function(names, meta, path_store) {
+tar_delete_cloud_objects <- function(names, meta, path_store) {
+  tar_message_meta(store = path_store)
   index_cloud <- !is.na(meta$repository) & meta$repository != "local"
   meta <- meta[index_cloud,, drop = FALSE] # nolint
   meta <- meta[meta$name %in% names,, drop = FALSE] # nolint
