@@ -8,6 +8,7 @@
 #'   back into R, and see
 #'   <https://docs.ropensci.org/targets/reference/index.html#clean>
 #'   to manage output files.
+#' @inheritSection tar_meta Storage access
 #' @return `NULL` except if `callr_function = callr::r_bg()`, in which case
 #'   a handle to the `callr` background process is returned. Either way,
 #'   the value is invisibly returned.
@@ -48,14 +49,29 @@
 #'     steps like data retrieval and output storage.
 #'   * `"verbose_positives"`: same as the `"verbose"` reporter
 #'     except without messages for skipped targets.
-#' @param seconds_interval Positive numeric of length 1 with the minimum
-#'   number of seconds between saves to the metadata and progress data.
-#'   Also controls how often the reporter prints progress messages.
+#' @param seconds_interval Deprecated on 2023-08-24 (version 1.2.2.9001).
+#'   Use `seconds_meta_append`, `seconds_meta_upload`,
+#'   and `seconds_reporter` instead.
+#' @param seconds_meta_append Positive numeric of length 1 with the minimum
+#'   number of seconds between saves to the local metadata and progress files
+#'   in the data store.
 #'   Higher values generally make the pipeline run faster, but unsaved
 #'   work (in the event of a crash) is not up to date.
-#'   When a target starts or the pipeline ends,
-#'   everything is saved/printed immediately,
-#'   regardless of `seconds_interval`.
+#'   When the pipeline ends,
+#'   all the metadata and progress data is saved immediately,
+#'   regardless of `seconds_meta_append`.
+#' @param seconds_meta_upload Positive numeric of length 1 with the minimum
+#'   number of seconds between uploads of the metadata and progress data
+#'   to the cloud
+#'   (see <https://books.ropensci.org/targets/cloud-storage.html>).
+#'   Higher values generally make the pipeline run faster, but unsaved
+#'   work (in the event of a crash) may not be backed up to the cloud.
+#'   When the pipeline ends,
+#'   all the metadata and progress data is uploaded immediately,
+#'   regardless of `seconds_meta_upload`.
+#' @param seconds_reporter Positive numeric of length 1 with the minimum
+#'   number of seconds between times when the reporter prints progress
+#'   messages to the R console.
 #' @param garbage_collection Logical of length 1. For a `crew`-integrated
 #'   pipeline, whether to run garbage collection on the main process
 #'   before sending a target
@@ -109,6 +125,9 @@ tar_make <- function(
   names = NULL,
   shortcut = targets::tar_config_get("shortcut"),
   reporter = targets::tar_config_get("reporter_make"),
+  seconds_meta_append = targets::tar_config_get("seconds_meta_append"),
+  seconds_meta_upload = targets::tar_config_get("seconds_meta_upload"),
+  seconds_reporter = targets::tar_config_get("seconds_reporter"),
   seconds_interval = targets::tar_config_get("seconds_interval"),
   callr_function = callr::r,
   callr_arguments = targets::tar_callr_args_default(callr_function, reporter),
@@ -119,16 +138,26 @@ tar_make <- function(
   use_crew = targets::tar_config_get("use_crew"),
   terminate_controller = TRUE
 ) {
+  tar_assert_allow_meta("tar_make")
   force(envir)
   tar_assert_scalar(shortcut)
   tar_assert_lgl(shortcut)
   tar_assert_flag(reporter, tar_reporters_make())
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
-  tar_assert_dbl(seconds_interval)
-  tar_assert_scalar(seconds_interval)
-  tar_assert_none_na(seconds_interval)
-  tar_assert_ge(seconds_interval, 0)
+  tar_assert_dbl(seconds_meta_append)
+  tar_assert_scalar(seconds_meta_append)
+  tar_assert_none_na(seconds_meta_append)
+  tar_assert_ge(seconds_meta_append, 0)
+  tar_assert_dbl(seconds_meta_upload)
+  tar_assert_scalar(seconds_meta_upload)
+  tar_assert_none_na(seconds_meta_upload)
+  tar_assert_ge(seconds_meta_upload, 0)
+  tar_assert_dbl(seconds_reporter)
+  tar_assert_scalar(seconds_reporter)
+  tar_assert_none_na(seconds_reporter)
+  tar_assert_ge(seconds_reporter, 0)
+  tar_deprecate_seconds_interval(seconds_interval)
   tar_assert_lgl(garbage_collection)
   tar_assert_scalar(garbage_collection)
   tar_assert_none_na(garbage_collection)
@@ -140,7 +169,9 @@ tar_make <- function(
     names_quosure = rlang::enquo(names),
     shortcut = shortcut,
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     garbage_collection = garbage_collection,
     use_crew = use_crew,
     terminate_controller = terminate_controller
@@ -164,7 +195,9 @@ tar_make_inner <- function(
   names_quosure,
   shortcut,
   reporter,
-  seconds_interval,
+  seconds_meta_append,
+  seconds_meta_upload,
+  seconds_reporter,
   garbage_collection,
   use_crew,
   terminate_controller
@@ -185,7 +218,9 @@ tar_make_inner <- function(
       shortcut = shortcut,
       queue = queue,
       reporter = reporter,
-      seconds_interval = seconds_interval,
+      seconds_meta_append = seconds_meta_append,
+      seconds_meta_upload = seconds_meta_upload,
+      seconds_reporter = seconds_reporter,
       envir = tar_option_get("envir")
     )$run()
   } else {
@@ -197,7 +232,9 @@ tar_make_inner <- function(
       shortcut = shortcut,
       queue = "parallel",
       reporter = reporter,
-      seconds_interval = seconds_interval,
+      seconds_meta_append = seconds_meta_append,
+      seconds_meta_upload = seconds_meta_upload,
+      seconds_reporter = seconds_reporter,
       garbage_collection = garbage_collection,
       envir = tar_option_get("envir"),
       controller = controller,
