@@ -1,7 +1,8 @@
-#' @title Run a pipeline with persistent `clustermq` workers.
+#' @title Superseded. Run a pipeline with persistent `clustermq` workers.
 #' @export
 #' @family pipeline
-#' @description Run a pipeline with persistent `clustermq` workers.
+#' @description Superseded. Use [tar_make()] with `crew`:
+#'   <https://books.ropensci.org/targets/crew.html>.
 #' @details `tar_make_clustermq()` is like [tar_make()] except that targets
 #'   run in parallel on persistent workers. A persistent worker is an
 #'   R process that runs for a long time and builds multiple
@@ -19,6 +20,7 @@
 #'   or <https://books.ropensci.org/targets/hpc.html>.
 #'   `clustermq` is not a strict dependency of `targets`,
 #'   so you must install `clustermq` yourself.
+#' @inheritSection tar_meta Storage access
 #' @return `NULL` except if `callr_function = callr::r_bg()`, in which case
 #'   a handle to the `callr` background process is returned. Either way,
 #'   the value is invisibly returned.
@@ -45,6 +47,9 @@ tar_make_clustermq <- function(
   names = NULL,
   shortcut = targets::tar_config_get("shortcut"),
   reporter = targets::tar_config_get("reporter_make"),
+  seconds_meta_append = targets::tar_config_get("seconds_meta_append"),
+  seconds_meta_upload = targets::tar_config_get("seconds_meta_upload"),
+  seconds_reporter = targets::tar_config_get("seconds_reporter"),
   seconds_interval = targets::tar_config_get("seconds_interval"),
   workers = targets::tar_config_get("workers"),
   log_worker = FALSE,
@@ -60,6 +65,7 @@ tar_make_clustermq <- function(
   # Cannot use multicore clustermq backend
   # due to https://github.com/ropensci/targets/discussions/780
   # nocov start
+  tar_assert_allow_meta("tar_make_clustermq")
   force(envir)
   tar_assert_package("clustermq")
   tar_assert_scalar(shortcut)
@@ -70,10 +76,19 @@ tar_make_clustermq <- function(
   tar_assert_ge(workers, 1)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
-  tar_assert_dbl(seconds_interval)
-  tar_assert_scalar(seconds_interval)
-  tar_assert_none_na(seconds_interval)
-  tar_assert_ge(seconds_interval, 0)
+  tar_assert_dbl(seconds_meta_append)
+  tar_assert_scalar(seconds_meta_append)
+  tar_assert_none_na(seconds_meta_append)
+  tar_assert_ge(seconds_meta_append, 0)
+  tar_assert_dbl(seconds_meta_upload)
+  tar_assert_scalar(seconds_meta_upload)
+  tar_assert_none_na(seconds_meta_upload)
+  tar_assert_ge(seconds_meta_upload, 0)
+  tar_assert_dbl(seconds_reporter)
+  tar_assert_scalar(seconds_reporter)
+  tar_assert_none_na(seconds_reporter)
+  tar_assert_ge(seconds_reporter, 0)
+  tar_deprecate_seconds_interval(seconds_interval)
   tar_assert_lgl(garbage_collection)
   tar_assert_scalar(garbage_collection)
   tar_assert_none_na(garbage_collection)
@@ -82,7 +97,9 @@ tar_make_clustermq <- function(
     names_quosure = rlang::enquo(names),
     shortcut = shortcut,
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     garbage_collection = garbage_collection,
     workers = workers,
     log_worker = log_worker
@@ -106,7 +123,9 @@ tar_make_clustermq_inner <- function(
   names_quosure,
   shortcut,
   reporter,
-  seconds_interval,
+  seconds_meta_append,
+  seconds_meta_upload,
+  seconds_reporter,
   garbage_collection,
   workers,
   log_worker
@@ -119,7 +138,9 @@ tar_make_clustermq_inner <- function(
     shortcut = shortcut,
     queue = "parallel",
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     garbage_collection = garbage_collection,
     envir = tar_option_get("envir"),
     workers = workers,
