@@ -1,15 +1,19 @@
-#' @title Run a pipeline of targets in parallel with transient
+#' @title Superseded. Run a pipeline of targets in parallel with transient
 #'   `future` workers.
 #' @export
 #' @family pipeline
-#' @description This function is like [tar_make()] except that targets
+#' @description Superseded. Use [tar_make()] with `crew`:
+#'   <https://books.ropensci.org/targets/crew.html>.
+#' @details This function is like [tar_make()] except that targets
 #'   run in parallel with transient `future` workers. It requires
 #'   that you declare your `future::plan()` inside the
 #'   target script file (default: `_targets.R`).
 #'   `future` is not a strict dependency of `targets`,
 #'   so you must install `future` yourself.
-#' @details To configure `tar_make_future()` with a computing cluster,
+#'
+#'   To configure `tar_make_future()` with a computing cluster,
 #'   see the `future.batchtools` package documentation.
+#' @inheritSection tar_meta Storage access
 #' @return `NULL` except if `callr_function = callr::r_bg()`, in which case
 #'   a handle to the `callr` background process is returned. Either way,
 #'   the value is invisibly returned.
@@ -37,6 +41,9 @@ tar_make_future <- function(
   names = NULL,
   shortcut = targets::tar_config_get("shortcut"),
   reporter = targets::tar_config_get("reporter_make"),
+  seconds_meta_append = targets::tar_config_get("seconds_meta_append"),
+  seconds_meta_upload = targets::tar_config_get("seconds_meta_upload"),
+  seconds_reporter = targets::tar_config_get("seconds_reporter"),
   seconds_interval = targets::tar_config_get("seconds_interval"),
   workers = targets::tar_config_get("workers"),
   callr_function = callr::r,
@@ -46,6 +53,7 @@ tar_make_future <- function(
   store = targets::tar_config_get("store"),
   garbage_collection = targets::tar_config_get("garbage_collection")
 ) {
+  tar_assert_allow_meta("tar_make_future")
   force(envir)
   tar_assert_package("future")
   tar_assert_scalar(shortcut)
@@ -56,10 +64,19 @@ tar_make_future <- function(
   tar_assert_ge(workers, 1)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
-  tar_assert_dbl(seconds_interval)
-  tar_assert_scalar(seconds_interval)
-  tar_assert_none_na(seconds_interval)
-  tar_assert_ge(seconds_interval, 0)
+  tar_assert_dbl(seconds_meta_append)
+  tar_assert_scalar(seconds_meta_append)
+  tar_assert_none_na(seconds_meta_append)
+  tar_assert_ge(seconds_meta_append, 0)
+  tar_assert_dbl(seconds_meta_upload)
+  tar_assert_scalar(seconds_meta_upload)
+  tar_assert_none_na(seconds_meta_upload)
+  tar_assert_ge(seconds_meta_upload, 0)
+  tar_assert_dbl(seconds_reporter)
+  tar_assert_scalar(seconds_reporter)
+  tar_assert_none_na(seconds_reporter)
+  tar_assert_ge(seconds_reporter, 0)
+  tar_deprecate_seconds_interval(seconds_interval)
   tar_assert_lgl(garbage_collection)
   tar_assert_scalar(garbage_collection)
   tar_assert_none_na(garbage_collection)
@@ -68,7 +85,9 @@ tar_make_future <- function(
     names_quosure = rlang::enquo(names),
     shortcut = shortcut,
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     garbage_collection = garbage_collection,
     workers = workers
   )
@@ -91,7 +110,9 @@ tar_make_future_inner <- function(
   names_quosure,
   shortcut,
   reporter,
-  seconds_interval,
+  seconds_meta_append,
+  seconds_meta_upload,
+  seconds_reporter,
   garbage_collection,
   workers
 ) {
@@ -103,7 +124,9 @@ tar_make_future_inner <- function(
     shortcut = shortcut,
     queue = "parallel",
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     garbage_collection = garbage_collection,
     workers = workers
   )$run()
