@@ -6,6 +6,7 @@
 #' @details `mermaid.js` is a JavaScript library for constructing
 #'   static visualizations of graphs.
 #' @inheritSection tar_network Dependency graph
+#' @inheritSection tar_meta Storage access
 #' @return A character vector of lines of code of the `mermaid.js` graph.
 #'   You can visualize the graph by copying the text
 #'   into a public online `mermaid.js` editor or a `mermaid` GitHub code chunk
@@ -48,12 +49,14 @@ tar_mermaid <- function(
   legend = TRUE,
   color = TRUE,
   reporter = targets::tar_config_get("reporter_outdated"),
+  seconds_reporter = targets::tar_config_get("seconds_reporter"),
   callr_function = callr::r,
   callr_arguments = targets::tar_callr_args_default(callr_function),
   envir = parent.frame(),
   script = targets::tar_config_get("script"),
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_mermaidd")
   force(envir)
   tar_assert_lgl(targets_only, "targets_only must be logical.")
   tar_assert_lgl(outdated, "outdated in tar_mermaid() must be logical.")
@@ -65,6 +68,10 @@ tar_mermaid <- function(
   tar_config_assert_reporter_outdated(reporter)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments, "callr_arguments mut be a list.")
+  tar_assert_dbl(seconds_reporter)
+  tar_assert_scalar(seconds_reporter)
+  tar_assert_none_na(seconds_reporter)
+  tar_assert_ge(seconds_reporter, 0)
   targets_arguments <- list(
     path_store = store,
     targets_only = targets_only,
@@ -76,7 +83,8 @@ tar_mermaid <- function(
     label = label,
     legend = legend,
     color = color,
-    reporter = reporter
+    reporter = reporter,
+    seconds_reporter = seconds_reporter
   )
   callr_outer(
     targets_function = tar_mermaid_inner,
@@ -102,7 +110,8 @@ tar_mermaid_inner <- function(
   label,
   legend,
   color,
-  reporter
+  reporter,
+  seconds_reporter
 ) {
   names <- tar_tidyselect_eval(names_quosure, pipeline_get_names(pipeline))
   network <- inspection_init(
@@ -115,7 +124,8 @@ tar_mermaid_inner <- function(
     allow = allow_quosure,
     exclude = exclude_quosure,
     outdated = outdated,
-    reporter = reporter
+    reporter = reporter,
+    seconds_reporter = seconds_reporter
   )
   visual <- mermaid_init(
     network = network,
