@@ -11,6 +11,7 @@
 #'   check the status with `tar_pid() %in% ps::ps_pids()`
 #'   before running another call to [tar_make()]
 #'   for the same project.
+#' @inheritSection tar_meta Storage access
 #' @return A data frame with metadata on the most recent main R process
 #'   to orchestrate the targets of the current project.
 #'   The output includes the `pid` of the main process.
@@ -39,6 +40,7 @@ tar_process <- function(
   names = NULL,
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_process")
   tar_assert_scalar(store)
   tar_assert_chr(store)
   tar_assert_nzchar(store)
