@@ -3,6 +3,7 @@
 #' @family progress
 #' @description Read a project's target progress data for the most recent
 #'   run of [tar_make()] or similar. Only the most recent record is shown.
+#' @inheritSection tar_meta Storage access
 #' @return A data frame with one row per target and the following columns:
 #'   * `name`: name of the target.
 #'   * `type`: type of target: `"stem"` for non-branching targets,
@@ -41,6 +42,7 @@ tar_progress <- function(
   fields = "progress",
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_progress")
   tar_assert_scalar(store)
   tar_assert_chr(store)
   tar_assert_nzchar(store)
