@@ -15,8 +15,12 @@
 #'   bucket to upload and download the return values
 #'   of the affected targets during the pipeline.
 #' @param prefix Character of length 1, "directory path"
-#'   in the bucket where the target return values are stored.
-#'   Defaults to `targets::tar_path_objects_dir_cloud()`.
+#'   in the bucket where your target object and metadata will go.
+#'   Please supply an explicit prefix
+#'   unique to your {targets} project.
+#'   In the future, {targets} will begin requiring
+#'   explicitly user-supplied prefixes. (This last note
+#'   was added on 2023-08-24: {targets} version 1.2.2.9000.)
 #' @param region Character of length 1, AWS region containing the S3 bucket.
 #'   Set to `NULL` to use the default region.
 #' @param part_size Positive numeric of length 1, number of bytes
@@ -28,7 +32,10 @@
 #'   Defaults to the Amazon AWS endpoint if `NULL`. Example:
 #'   To use the S3 protocol with Google Cloud Storage,
 #'   set `endpoint = "https://storage.googleapis.com"`
-#'   and `region = "auto"`. Also make sure to create
+#'   and `region = "auto"`. (A custom endpoint may require that you
+#'   explicitly set a custom region directly in `tar_resources_aws()`.
+#'   `region = "auto"` happens to work with Google Cloud.)
+#'   Also make sure to create
 #'   HMAC access keys in the Google Cloud Storage console
 #'   (under Settings => Interoperability) and set the
 #'   `AWS_ACCESS_KEY_ID` and `AWS_SECRET_ACCESS_KEY` environment
@@ -38,6 +45,14 @@
 #'   object versioning turned on, `targets` may fail to record object
 #'   versions. Google Cloud Storage in particular has this
 #'   incompatibility.
+#' @param max_tries Positive integer of length 1, maximum number of attempts
+#'   to access a network resource on AWS.
+#' @param seconds_timeout Positive numeric of length 1,
+#'   number of seconds until an HTTP connection times out.
+#' @param close_connection Logical of length 1, whether to close HTTP
+#'   connections immediately.
+#' @param s3_force_path_style Logical of length 1, whether to use path-style
+#'   addressing for S3 requests.
 #' @param ... Named arguments to functions in `paws.storage::s3()` to manage
 #'   S3 storage. The documentation of these specific functions
 #'   is linked from `https://www.paws-r-sdk.com/docs/s3/`.
@@ -76,8 +91,18 @@ tar_resources_aws <- function(
   region = targets::tar_option_get("resources")$aws$region,
   part_size = targets::tar_option_get("resources")$aws$part_size,
   endpoint = targets::tar_option_get("resources")$aws$endpoint,
+  max_tries = targets::tar_option_get("resources")$aws$max_tries,
+  seconds_timeout = targets::tar_option_get("resources")$aws$seconds_timeout,
+  close_connection = targets::tar_option_get("resources")$aws$close_connection,
+  s3_force_path_style = targets::tar_option_get(
+    "resources"
+  )$aws$s3_force_path_style,
   ...
 ) {
+  if (is.null(prefix)) {
+    tar_warn_prefix()
+    prefix <- path_store_default()
+  }
   prefix <- prefix %|||% targets::tar_path_objects_dir_cloud()
   part_size <- part_size %|||% (5 * (2 ^ 20))
   args <- list(...)
@@ -91,6 +116,10 @@ tar_resources_aws <- function(
     region = region,
     part_size = part_size,
     endpoint = endpoint,
+    max_tries = max_tries,
+    seconds_timeout = seconds_timeout,
+    close_connection = close_connection,
+    s3_force_path_style = s3_force_path_style,
     args = args
   )
   resources_validate(out)
