@@ -77,8 +77,8 @@
 #'     Always `NA` if the `record` cue is activated.
 #'     Otherwise, always `FALSE` if the `file` cue is suppressed.
 #' @examples
-#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) {
-#' tar_dir({ # tar_dir() runs code from a temporary directory.
+#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) { # for CRAN
+#' tar_dir({ # tar_dir() runs code from a temp dir for CRAN.
 #' tar_script({
 #'   list(
 #'     tar_target(x, seq_len(2)),
@@ -101,6 +101,7 @@ tar_sitrep <- function(
   script = targets::tar_config_get("script"),
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_sitrep")
   force(envir)
   names_quosure <- rlang::enquo(names)
   fields_quosure <- rlang::enquo(fields)
@@ -109,6 +110,7 @@ tar_sitrep <- function(
   tar_assert_flag(reporter, tar_reporters_outdated())
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
+  tar_message_meta(store = store)
   targets_arguments <- list(
     path_store = store,
     names_quosure = rlang::enquo(names),
