@@ -4,6 +4,7 @@
 #' @description Visualize the pipeline dependency graph with a `visNetwork`
 #'   HTML widget.
 #' @inheritSection tar_network Dependency graph
+#' @inheritSection tar_meta Storage access
 #' @return A `visNetwork` HTML widget object.
 #' @inheritParams tar_glimpse
 #' @inheritParams tar_network
@@ -41,12 +42,14 @@ tar_visnetwork <- function(
   degree_to = 1L,
   zoom_speed = 1,
   reporter = targets::tar_config_get("reporter_outdated"),
+  seconds_reporter = targets::tar_config_get("seconds_reporter"),
   callr_function = callr::r,
   callr_arguments = targets::tar_callr_args_default(callr_function),
   envir = parent.frame(),
   script = targets::tar_config_get("script"),
   store = targets::tar_config_get("store")
 ) {
+  tar_assert_allow_meta("tar_visnetwork")
   force(envir)
   tar_assert_package("visNetwork")
   tar_assert_lgl(targets_only, "targets_only must be logical.")
@@ -62,6 +65,10 @@ tar_visnetwork <- function(
   tar_assert_dbl(zoom_speed)
   tar_assert_positive(zoom_speed)
   tar_config_assert_reporter_outdated(reporter)
+  tar_assert_dbl(seconds_reporter)
+  tar_assert_scalar(seconds_reporter)
+  tar_assert_none_na(seconds_reporter)
+  tar_assert_ge(seconds_reporter, 0)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments, "callr_arguments mut be a list.")
   targets_arguments <- list(
@@ -77,7 +84,8 @@ tar_visnetwork <- function(
     degree_from = degree_from,
     degree_to = degree_to,
     zoom_speed = zoom_speed,
-    reporter = reporter
+    reporter = reporter,
+    seconds_reporter = seconds_reporter
   )
   callr_outer(
     targets_function = tar_visnetwork_inner,
@@ -105,7 +113,8 @@ tar_visnetwork_inner <- function(
   degree_from,
   degree_to,
   zoom_speed,
-  reporter
+  reporter,
+  seconds_reporter
 ) {
   names <- tar_tidyselect_eval(names_quosure, pipeline_get_names(pipeline))
   network <- inspection_init(
@@ -118,7 +127,8 @@ tar_visnetwork_inner <- function(
     allow = allow_quosure,
     exclude = exclude_quosure,
     outdated = outdated,
-    reporter = reporter
+    reporter = reporter,
+    seconds_reporter = seconds_reporter
   )
   visual <- visnetwork_init(
     network = network,
