@@ -18,6 +18,7 @@ tar_watch_server <- function(
   config = Sys.getenv("TAR_CONFIG", "_targets.yaml"),
   project = Sys.getenv("TAR_PROJECT", "main")
 ) {
+  tar_assert_allow_meta("tar_watch_server")
   tar_assert_watch_packages()
   tar_assert_chr(
     exclude,
@@ -115,7 +116,7 @@ tar_watch_server <- function(
         out <- tar_progress(fields = everything(), store = path_store)
         if (tar_exist_meta(store = path_store)) {
           fields <- c("name", "time", "seconds", "bytes", "error", "warnings")
-          meta <- tar_meta(fields = all_of(fields), store = path_store)
+          meta <- tar_meta(fields = any_of(fields), store = path_store)
           meta$finished <- as.character(meta$time)
           meta$time <- units_seconds(meta$seconds)
           meta$size <- units_bytes(meta$bytes)
