@@ -42,6 +42,7 @@ tar_watch_ui <- function(
   display = "summary",
   displays = c("summary", "branches", "progress", "graph", "about")
 ) {
+  tar_assert_allow_meta("tar_watch_ui")
   tar_assert_watch_packages()
   tar_assert_dbl(seconds)
   tar_assert_dbl(seconds_min)
@@ -74,8 +75,7 @@ tar_watch_ui <- function(
       closable = FALSE,
       collapsible = FALSE,
       width = 3,
-      # TODO: update when bs4Dash 2 is on CRAN:
-      solidHeader = utils::packageVersion("bs4Dash") >= 2L,
+      solidHeader = TRUE,
       shinyWidgets::radioGroupButtons(
         inputId = ns("display"),
         label = NULL,
@@ -170,8 +170,7 @@ tar_watch_ui <- function(
       status = "primary",
       closable = FALSE,
       collapsible = FALSE,
-      # TODO: update when bs4Dash 2 is on CRAN:
-      solidHeader = utils::packageVersion("bs4Dash") >= 2L,
+      solidHeader = TRUE,
       width = 9,
       shiny::uiOutput(ns("display"))
     )
