@@ -10,7 +10,7 @@ tar_test("aws_qs format data gets stored", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -22,10 +22,18 @@ tar_test("aws_qs format data gets stored", {
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL)
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/x")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/x",
+      max_tries = 1L
+    )
   )
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/y")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/y",
+      max_tries = 1L
+    )
   )
   expect_false(file.exists(file.path("_targets", "objects", "x")))
   expect_false(file.exists(file.path("_targets", "objects", "y")))
@@ -35,7 +43,8 @@ tar_test("aws_qs format data gets stored", {
   aws_s3_download(
     key = "_targets/objects/x",
     bucket = bucket_name,
-    file = tmp
+    file = tmp,
+    max_tries = 1L
   )
   expect_equal(qs::qread(tmp), "x_value")
 })
@@ -50,7 +59,7 @@ tar_test("aws_qs format data gets stored with worker storage", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       ),
       storage = "worker",
       retrieval = "worker"
@@ -64,10 +73,18 @@ tar_test("aws_qs format data gets stored with worker storage", {
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL)
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/x")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/x",
+      max_tries = 1L
+    )
   )
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/y")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/y",
+      max_tries = 1L
+    )
   )
   expect_false(file.exists(file.path("_targets", "objects", "x")))
   expect_false(file.exists(file.path("_targets", "objects", "y")))
@@ -77,7 +94,8 @@ tar_test("aws_qs format data gets stored with worker storage", {
   aws_s3_download(
     key = "_targets/objects/x",
     bucket = bucket_name,
-    file = tmp
+    file = tmp,
+    max_tries = 1L
   )
   expect_equal(qs::qread(tmp), "x_value")
 })
@@ -92,7 +110,7 @@ tar_test("aws_qs format invalidation", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -112,7 +130,7 @@ tar_test("aws_qs format invalidation", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -139,7 +157,7 @@ tar_test("aws_qs format and dynamic branching", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       ),
       storage = "worker",
       retrieval = "worker",
@@ -171,7 +189,7 @@ tar_test("aws timestamp", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       ),
       format = "qs",
       repository = "aws"
@@ -201,7 +219,7 @@ tar_test("aws_qs format with an alternative data store", {
   on.exit(aws_s3_delete_bucket(bucket_name))
   expr <- quote({
     tar_option_set(resources = tar_resources(
-      aws = tar_resources_aws(bucket = !!bucket_name)
+      aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
     ))
     list(
       tar_target(x, "x_value", format = "qs", repository = "aws"),
@@ -214,10 +232,18 @@ tar_test("aws_qs format with an alternative data store", {
   expect_true(file.exists("custom_targets_store"))
   expect_false(file.exists(path_store_default()))
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/x")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/x",
+      max_tries = 1L
+    )
   )
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/y")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/y",
+      max_tries = 1L
+    )
   )
   expect_false(file.exists(file.path("_targets", "objects", "x")))
   expect_false(file.exists(file.path("_targets", "objects", "y")))
@@ -227,7 +253,8 @@ tar_test("aws_qs format with an alternative data store", {
   aws_s3_download(
     key = "_targets/objects/x",
     bucket = bucket_name,
-    file = tmp
+    file = tmp,
+    max_tries = 1L
   )
   expect_equal(qs::qread(tmp), "x_value")
 })
@@ -242,7 +269,7 @@ tar_test("aws_qs format works with storage = \"none\"", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -260,10 +287,18 @@ tar_test("aws_qs format works with storage = \"none\"", {
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
   tar_make(callr_function = NULL)
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/x")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/x",
+      max_tries = 1L
+    )
   )
   expect_true(
-    aws_s3_exists(bucket = bucket_name, key = "_targets/objects/y")
+    aws_s3_exists(
+      bucket = bucket_name,
+      key = "_targets/objects/y",
+      max_tries = 1L
+    )
   )
   expect_false(file.exists(file.path("_targets", "objects", "x")))
   expect_false(file.exists(file.path("_targets", "objects", "y")))
@@ -273,7 +308,8 @@ tar_test("aws_qs format works with storage = \"none\"", {
   aws_s3_download(
     key = "_targets/objects/x",
     bucket = bucket_name,
-    file = tmp
+    file = tmp,
+    max_tries = 1L
   )
   expect_equal(qs::qread(tmp), "x_value")
 })
@@ -283,14 +319,26 @@ tar_test("aws_qs format with custom region", {
   skip_if_not_installed("qs")
   s3 <- paws.storage::s3()
   bucket_name <- random_bucket_name()
-  region <- "us-west-2"
+  region <- region <- ifelse(
+    Sys.getenv("AWS_REGION") == "us-east-1",
+    "us-east-2",
+    "us-east-1"
+  )
   cfg <- list(LocationConstraint = region)
   s3$create_bucket(Bucket = bucket_name, CreateBucketConfiguration = cfg)
   on.exit(aws_s3_delete_bucket(bucket_name))
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, region = !!region)
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          region = ifelse(
+            Sys.getenv("AWS_REGION") == "us-east-1",
+            "us-east-2",
+            "us-east-1"
+          ),
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -305,14 +353,16 @@ tar_test("aws_qs format with custom region", {
     aws_s3_exists(
       bucket = bucket_name,
       key = "_targets/objects/x",
-      region = "us-west-2"
+      region = region,
+      max_tries = 1L
     )
   )
   expect_true(
     aws_s3_exists(
       bucket = bucket_name,
       key = "_targets/objects/y",
-      region = "us-west-2"
+      region = region,
+      max_tries = 1L
     )
   )
   expect_false(file.exists(file.path("_targets", "objects", "x")))
@@ -324,7 +374,7 @@ tar_test("aws_qs format with custom region", {
     c(
       sprintf("bucket=%s", bucket_name),
       sprintf("endpoint=%s", base64url::base64_urlencode("NULL")),
-      "region=us-west-2",
+      paste0("region=", region),
       "key=_targets/objects/x",
       "version="
     )
@@ -335,7 +385,8 @@ tar_test("aws_qs format with custom region", {
     key = "_targets/objects/x",
     bucket = bucket_name,
     file = tmp,
-    region = region
+    region = region,
+    max_tries = 1L
   )
   expect_equal(qs::qread(tmp), "x_value")
 })
@@ -350,7 +401,11 @@ tar_test("aws_qs format empty region string", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, region = "")
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          region = "",
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -373,7 +428,11 @@ tar_test("aws_qs nonexistent bucket", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name, region = "")
+        aws = tar_resources_aws(
+          bucket = !!bucket_name,
+          region = "",
+          prefix = "_targets"
+        )
       )
     )
     list(
@@ -414,7 +473,7 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -436,7 +495,7 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -460,7 +519,7 @@ tar_test("aws_qs format versioning", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
@@ -484,7 +543,7 @@ tar_test("cloud target paths are not in the file path cache", {
   expr <- quote({
     tar_option_set(
       resources = tar_resources(
-        aws = tar_resources_aws(bucket = !!bucket_name)
+        aws = tar_resources_aws(bucket = !!bucket_name, prefix = "_targets")
       )
     )
     list(
