@@ -4,16 +4,33 @@ tar_test("aws_s3_exists()", {
   bucket <- random_bucket_name()
   paws.storage::s3()$create_bucket(Bucket = bucket)
   on.exit(aws_s3_delete_bucket(bucket))
-  expect_false(aws_s3_exists(key = "x", bucket = bucket))
-  tmp <- tempfile()
-  writeLines("x", tmp)
-  paws.storage::s3()$put_object(Body = tmp, Key = "x", Bucket = bucket)
-  expect_true(aws_s3_exists(key = "x", bucket = bucket))
   expect_false(
     aws_s3_exists(
       key = "x",
       bucket = bucket,
-      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b")
+      max_tries = 1L
+    )
+  )
+  tmp <- tempfile()
+  writeLines("x", tmp)
+  paws.storage::s3()$put_object(
+    Body = tmp,
+    Key = "x",
+    Bucket = bucket
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b"),
+      max_tries = 1L
     )
   )
 })
@@ -22,12 +39,28 @@ tar_test("aws_s3_head()", {
   bucket <- random_bucket_name()
   paws.storage::s3()$create_bucket(Bucket = bucket)
   on.exit(aws_s3_delete_bucket(bucket))
-  expect_null(aws_s3_head(key = "x", bucket = random_bucket_name()))
-  expect_null(aws_s3_head(key = "x", bucket = bucket))
+  expect_null(
+    aws_s3_head(
+      key = "x",
+      bucket = random_bucket_name(),
+      max_tries = 1L
+    )
+  )
+  expect_null(
+    aws_s3_head(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
   tmp <- tempfile()
   writeLines("x", tmp)
   paws.storage::s3()$put_object(Body = tmp, Key = "x", Bucket = bucket)
-  head <- aws_s3_head(key = "x", bucket = bucket)
+  head <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    max_tries = 1L
+  )
   expect_true(is.list(head))
   expect_true(is.character(head$ETag))
   expect_true(nzchar(head$ETag))
@@ -35,7 +68,8 @@ tar_test("aws_s3_head()", {
     aws_s3_head(
       key = "x",
       bucket = bucket,
-      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b")
+      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b"),
+      max_tries = 1L
     )
   )
 })
@@ -49,15 +83,21 @@ tar_test("aws_s3_download()", {
   paws.storage::s3()$put_object(Body = tmp, Key = "x", Bucket = bucket)
   tmp2 <- tempfile()
   expect_false(file.exists(tmp2))
-  aws_s3_download(file = tmp2, key = "x", bucket = bucket)
+  aws_s3_download(
+    file = tmp2,
+    key = "x",
+    bucket = bucket,
+    max_tries = 1L
+  )
   expect_error(
     aws_s3_download(
       file = tmp2,
       key = "x",
       bucket = bucket,
-      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b")
+      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b"),
+      max_tries = 1L
     ),
-    class = "http_error"
+    class = "http_400"
   )
   expect_equal(readLines(tmp2), "x")
 })
@@ -70,19 +110,46 @@ tar_test("aws_s3_delete()", {
   writeLines("x", tmp)
   key <- "x"
   paws.storage::s3()$put_object(Body = tmp, Key = key, Bucket = bucket)
-  expect_true(aws_s3_exists(key = key, bucket = bucket))
+  expect_true(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
   expect_error(
     aws_s3_delete(
       key = key,
       bucket = bucket,
-      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b")
+      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b"),
+      max_tries = 1L
     ),
-    class = "http_error"
+    class = "http_400"
+  )
+  expect_true(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
+  aws_s3_delete(
+    key = key,
+    bucket = bucket,
+    max_tries = 1L
+  )
+  expect_false(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
+  aws_s3_delete(
+    key = key,
+    bucket = bucket,
+    max_tries = 1L
   )
-  expect_true(aws_s3_exists(key = key, bucket = bucket))
-  aws_s3_delete(key = key, bucket = bucket)
-  expect_false(aws_s3_exists(key = key, bucket = bucket))
-  aws_s3_delete(key = key, bucket = bucket)
 })
 
 tar_test("aws_s3_delete() version", {
@@ -104,18 +171,57 @@ tar_test("aws_s3_delete() version", {
   writeLines("y", tmp)
   head2 <- paws.storage::s3()$put_object(Body = tmp, Key = key, Bucket = bucket)
   version2 <- head2$VersionId
-  expect_true(aws_s3_exists(key = key, bucket = bucket, version = version1))
-  expect_true(aws_s3_exists(key = key, bucket = bucket, version = version2))
-  aws_s3_delete(key = key, bucket = bucket, version = version1)
-  expect_false(aws_s3_exists(key = key, bucket = bucket, version = version1))
-  expect_true(aws_s3_exists(key = key, bucket = bucket, version = version2))
+  expect_true(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      version = version1,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      version = version2,
+      max_tries = 1L
+    )
+  )
+  aws_s3_delete(
+    key = key,
+    bucket = bucket,
+    version = version1,
+    max_tries = 1L
+  )
+  expect_false(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      version = version1,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = key,
+      bucket = bucket,
+      version = version2,
+      max_tries = 1L
+    )
+  )
 })
 
 tar_test("aws_s3_upload() without headers", {
   bucket <- random_bucket_name()
   paws.storage::s3()$create_bucket(Bucket = bucket)
   on.exit(aws_s3_delete_bucket(bucket))
-  expect_false(aws_s3_exists(key = "x", bucket = bucket))
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
   tmp <- tempfile()
   writeLines("x", tmp)
   expect_error(
@@ -123,28 +229,54 @@ tar_test("aws_s3_upload() without headers", {
       file = tmp,
       key = "x",
       bucket = bucket,
-      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b")
+      args = list(ExpectedBucketOwner = "phantom_f4acd87c52d4e62b"),
+      max_tries = 1L
     ),
-    class = "http_error"
+    class = "http_400"
+  )
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
   )
-  expect_false(aws_s3_exists(key = "x", bucket = bucket))
   aws_s3_upload(
     file = tmp,
     key = "x",
-    bucket = bucket
+    bucket = bucket,
+    max_tries = 1L
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
   )
-  expect_true(aws_s3_exists(key = "x", bucket = bucket))
 })
 
 tar_test("aws_s3_upload() and download with metadata and region", {
   bucket <- random_bucket_name()
-  region <- "us-west-2"
-  paws.storage::s3()$create_bucket(
+  region <- ifelse(
+    Sys.getenv("AWS_REGION") == "us-east-1",
+    "us-east-2",
+    "us-east-1"
+  )
+  client <- paws.storage::s3(config = list(region = region))
+  client$create_bucket(
     Bucket = bucket,
     CreateBucketConfiguration = list(LocationConstraint = region)
   )
-  on.exit(aws_s3_delete_bucket(bucket))
-  expect_false(aws_s3_exists(key = "x", bucket = bucket, region = region))
+  on.exit(aws_s3_delete_bucket(bucket, client = client))
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      region = region,
+      max_tries = 1L
+    )
+  )
   tmp <- tempfile()
   writeLines("x", tmp)
   aws_s3_upload(
@@ -152,14 +284,33 @@ tar_test("aws_s3_upload() and download with metadata and region", {
     key = "x",
     bucket = bucket,
     metadata = list("custom" = "custom_metadata"),
-    region = region
+    region = region,
+    max_tries = 1L
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      region = region,
+      max_tries = 1L
+    )
+  )
+  head <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    region = region,
+    max_tries = 1L
   )
-  expect_true(aws_s3_exists(key = "x", bucket = bucket, region = region))
-  head <- aws_s3_head(key = "x", bucket = bucket, region = region)
   expect_equal(head$Metadata$custom, "custom_metadata")
   tmp2 <- tempfile()
   expect_false(file.exists(tmp2))
-  aws_s3_download(file = tmp2, key = "x", bucket = bucket, region = region)
+  aws_s3_download(
+    file = tmp2,
+    key = "x",
+    bucket = bucket,
+    region = region,
+    max_tries = 1L
+  )
   expect_equal(readLines(tmp2), "x")
 })
 
@@ -180,7 +331,8 @@ tar_test("upload twice, get the correct version", {
     file = tmp,
     key = "x",
     bucket = bucket,
-    metadata = list("custom" = "first-meta")
+    metadata = list("custom" = "first-meta"),
+    max_tries = 1L
   )
   v1 <- head_first$VersionId
   writeLines("second", tmp)
@@ -188,23 +340,73 @@ tar_test("upload twice, get the correct version", {
     file = tmp,
     key = "x",
     bucket = bucket,
-    metadata = list("custom" = "second-meta")
+    metadata = list("custom" = "second-meta"),
+    max_tries = 1L
   )
   v2 <- head_second$VersionId
-  expect_true(aws_s3_exists(key = "x", bucket = bucket))
-  expect_true(aws_s3_exists(key = "x", bucket = bucket, version = v1))
-  expect_true(aws_s3_exists(key = "x", bucket = bucket, version = v2))
-  expect_false(aws_s3_exists(key = "x", bucket = bucket, version = "v3"))
-  h1 <- aws_s3_head(key = "x", bucket = bucket, version = v1)
-  h2 <- aws_s3_head(key = "x", bucket = bucket, version = v2)
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = v1,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = v2,
+      max_tries = 1L
+    )
+  )
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = "v3",
+      max_tries = 1L
+    )
+  )
+  h1 <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    version = v1,
+    max_tries = 1L
+  )
+  h2 <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    version = v2,
+    max_tries = 1L
+  )
   expect_equal(h1$VersionId, v1)
   expect_equal(h2$VersionId, v2)
   expect_equal(h1$Metadata$custom, "first-meta")
   expect_equal(h2$Metadata$custom, "second-meta")
   unlink(tmp)
-  aws_s3_download(file = tmp, key = "x", bucket = bucket, version = v1)
+  aws_s3_download(
+    file = tmp,
+    key = "x",
+    bucket = bucket,
+    version = v1,
+    max_tries = 1L
+  )
   expect_equal(readLines(tmp), "first")
-  aws_s3_download(file = tmp, key = "x", bucket = bucket, version = v2)
+  aws_s3_download(
+    file = tmp,
+    key = "x",
+    bucket = bucket,
+    version = v2,
+    max_tries = 1L
+  )
   expect_equal(readLines(tmp), "second")
 })
 
@@ -226,7 +428,8 @@ tar_test("multipart: upload twice, get the correct version", {
     key = "x",
     bucket = bucket,
     multipart = TRUE,
-    metadata = list("custom" = "first-meta")
+    metadata = list("custom" = "first-meta"),
+    max_tries = 1L
   )
   v1 <- head_first$VersionId
   writeLines("second", tmp)
@@ -235,23 +438,73 @@ tar_test("multipart: upload twice, get the correct version", {
     key = "x",
     bucket = bucket,
     multipart = TRUE,
-    metadata = list("custom" = "second-meta")
+    metadata = list("custom" = "second-meta"),
+    max_tries = 1L
   )
   v2 <- head_second$VersionId
-  expect_true(aws_s3_exists(key = "x", bucket = bucket))
-  expect_true(aws_s3_exists(key = "x", bucket = bucket, version = v1))
-  expect_true(aws_s3_exists(key = "x", bucket = bucket, version = v2))
-  expect_false(aws_s3_exists(key = "x", bucket = bucket, version = "v3"))
-  h1 <- aws_s3_head(key = "x", bucket = bucket, version = v1)
-  h2 <- aws_s3_head(key = "x", bucket = bucket, version = v2)
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = v1,
+      max_tries = 1L
+    )
+  )
+  expect_true(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = v2,
+      max_tries = 1L
+    )
+  )
+  expect_false(
+    aws_s3_exists(
+      key = "x",
+      bucket = bucket,
+      version = "v3",
+      max_tries = 1L
+    )
+  )
+  h1 <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    version = v1,
+    max_tries = 1L
+  )
+  h2 <- aws_s3_head(
+    key = "x",
+    bucket = bucket,
+    version = v2,
+    max_tries = 1L
+  )
   expect_equal(h1$VersionId, v1)
   expect_equal(h2$VersionId, v2)
   expect_equal(h1$Metadata$custom, "first-meta")
   expect_equal(h2$Metadata$custom, "second-meta")
   unlink(tmp)
-  aws_s3_download(file = tmp, key = "x", bucket = bucket, version = v1)
+  aws_s3_download(
+    file = tmp,
+    key = "x",
+    bucket = bucket,
+    version = v1,
+    max_tries = 1L
+  )
   expect_equal(readLines(tmp), "first")
-  aws_s3_download(file = tmp, key = "x", bucket = bucket, version = v2)
+  aws_s3_download(
+    file = tmp,
+    key = "x",
+    bucket = bucket,
+    version = v2,
+    max_tries = 1L
+  )
   expect_equal(readLines(tmp), "second")
 })
 
@@ -267,7 +520,8 @@ tar_test("graceful error on multipart upload", {
       key = "x",
       bucket = bucket,
       multipart = TRUE,
-      part_size = 5e3
+      part_size = 5e3,
+      max_tries = 1L
     ),
     class = "tar_condition_file"
   )
