@@ -36,6 +36,23 @@ tar_test("database$get_data()", {
   expect_false(file.exists(db$path))
 })
 
+tar_test("database$get_data() with list columns", {
+  skip_cran()
+  pipeline <- pipeline_map()
+  algorithm <- local_init(pipeline)
+  algorithm$run()
+  out <- algorithm$meta$database$get_data()
+  expect_true(is.list(out$path))
+  expect_true(is.list(out$children))
+  expect_equal(
+    length(out$children[[which(out$name == "map1")]][[1L]]),
+    3L
+  )
+  expect_false(anyNA(out$name))
+  expect_true(all(nzchar(out$name)))
+  expect_equal(as.integer(anyDuplicated(out$name)), 0L)
+})
+
 tar_test("database$ensure_storage()", {
   out <- database_init(header = c("col1", "col2"))
   path <- out$path
@@ -378,3 +395,93 @@ tar_test("compare_working_directories()", {
     class = "tar_condition_run"
   )
 })
+
+tar_test("local database cloud methods", {
+  database <- database_init(repository = "local")
+  expect_null(database$download())
+  expect_null(database$upload())
+  expect_null(database$head())
+  expect_null(database$delete_cloud())
+})
+
+tar_test("database unknown repository", {
+  expect_error(
+    database_init(repository = "unknown"),
+    class = "tar_condition_validate"
+  )
+})
+
+tar_test("mock download",  {
+  x <- database_class$new(path = tempfile())
+  expect_equal(x$download(), "download")
+})
+
+tar_test("mock upload",  {
+  x <- database_class$new(path = tempfile())
+  expect_equal(x$upload(), "upload")
+})
+
+tar_test("mock head non-existent file",  {
+  x <- database_class$new(path = tempfile())
+  out <- x$head()
+  expect_false(out$exists)
+  expect_equal(out$time, file_time(info = list(mtime_numeric = 0)))
+})
+
+tar_test("mock head",  {
+  x <- database_class$new(path = tempfile())
+  file.create("path_cloud")
+  out <- x$head()
+  expect_true(out$exists)
+})
+
+tar_test("mock sync no action", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  expect_null(x$sync(verbose = TRUE))
+})
+
+tar_test("mock sync only cloud", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  file.create("path_cloud")
+  expect_equal(x$sync(verbose = TRUE), "download")
+})
+
+tar_test("mock sync only local", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  file.create(x$path)
+  expect_equal(x$sync(verbose = TRUE), "upload")
+})
+
+tar_test("mock sync only local", {
+  x <- database_class$new(path = tempfile(), key = "x")
+  file.create(x$path)
+  expect_equal(x$sync(verbose = TRUE), "upload")
+})
+
+tar_test("mock sync no action on agreement", {
+  x <- database_class$new(path = tempfile())
+  writeLines("lines", x$path)
+  file.copy(x$path, "path_cloud")
+  expect_null(x$sync(verbose = TRUE))
+})
+
+tar_test("mock sync cloud file more recent", {
+  old <- system.file("CITATION", package = "targets", mustWork = TRUE)
+  x <- database_class$new(path = old, key = "x")
+  writeLines("lines", "path_cloud")
+  expect_equal(x$sync(verbose = TRUE), "download")
+})
+
+tar_test("mock sync local file more recent", {
+  skip_cran()
+  x <- database_class$new(path = tempfile(), key = "x")
+  writeLines("lines", x$path)
+  old <- system.file("CITATION", package = "targets", mustWork = TRUE)
+  file.copy(
+    from = old,
+    to = "path_cloud",
+    copy.date = TRUE,
+    overwrite = TRUE
+  )
+  expect_equal(x$sync(verbose = TRUE), "upload")
+})
