@@ -136,22 +136,69 @@ tar_test("tar_config_set() with script and different yaml file", {
   expect_equal(tar_config_get("script", config = path), path_script_default())
 })
 
+tar_test("tar_config_set() with seconds_meta_append", {
+  skip_cran()
+  expect_false(file.exists("_targets.yaml"))
+  expect_equal(tar_config_get("seconds_meta_append"), 0)
+  path <- tempfile()
+  tar_config_set(seconds_meta_append = 10)
+  expect_equal(tar_config_get("seconds_meta_append"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  tar_config_set()
+  expect_equal(tar_config_get("seconds_meta_append"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  unlink("_targets.yaml")
+  expect_equal(tar_config_get("seconds_meta_append"), 0)
+})
+
+tar_test("tar_config_set() with seconds_meta_upload", {
+  skip_cran()
+  expect_false(file.exists("_targets.yaml"))
+  expect_equal(tar_config_get("seconds_meta_upload"), 15)
+  path <- tempfile()
+  tar_config_set(seconds_meta_upload = 10)
+  expect_equal(tar_config_get("seconds_meta_upload"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  tar_config_set()
+  expect_equal(tar_config_get("seconds_meta_upload"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  unlink("_targets.yaml")
+  expect_equal(tar_config_get("seconds_meta_upload"), 15)
+})
+
+tar_test("tar_config_set() with seconds_reporter", {
+  skip_cran()
+  expect_false(file.exists("_targets.yaml"))
+  expect_equal(tar_config_get("seconds_reporter"), 0)
+  path <- tempfile()
+  tar_config_set(seconds_reporter = 10)
+  expect_equal(tar_config_get("seconds_reporter"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  tar_config_set()
+  expect_equal(tar_config_get("seconds_reporter"), 10)
+  expect_true(file.exists("_targets.yaml"))
+  unlink("_targets.yaml")
+  expect_equal(tar_config_get("seconds_reporter"), 0)
+})
+
 tar_test("tar_config_set() with seconds_interval", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
-  expect_equal(tar_config_get("seconds_interval"), 0.5)
+  expect_null(tar_config_get("seconds_interval"))
   path <- tempfile()
-  tar_config_set(seconds_interval = 10)
+  expect_warning(
+    tar_config_set(seconds_interval = 10),
+    class = "tar_condition_deprecate"
+  )
   expect_equal(tar_config_get("seconds_interval"), 10)
   expect_true(file.exists("_targets.yaml"))
   tar_config_set()
   expect_equal(tar_config_get("seconds_interval"), 10)
   expect_true(file.exists("_targets.yaml"))
   unlink("_targets.yaml")
-  expect_equal(tar_config_get("seconds_interval"), 0.5)
+  expect_null(tar_config_get("seconds_interval"))
 })
 
-
 tar_test("tar_config_set() with store", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
